emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[nongnu] externals/caml b1139bc 146/197: merge version/4.00 at revision


From: Stefan Monnier
Subject: [nongnu] externals/caml b1139bc 146/197: merge version/4.00 at revision 12866
Date: Sat, 21 Nov 2020 01:19:56 -0500 (EST)

branch: externals/caml
commit b1139bcc395f0647e8d34fc1443ad62521a787de
Author: Jacques Garrigue <garrigue at math.nagoya-u.ac.jp>
Commit: Jacques Garrigue <garrigue at math.nagoya-u.ac.jp>

    merge version/4.00 at revision 12866
    
    git-svn-id: http://caml.inria.fr/svn/ocaml/branches/short-paths@12869 
f963ae5c-01c2-4b8c-9fe0-0dff7051ff02
---
 Makefile      |  1 +
 README        | 10 +++++-----
 README.itz    | 26 +++++++++++++-------------
 caml-hilit.el |  2 +-
 caml-types.el | 39 +++++++++++++++++++--------------------
 caml.el       | 18 +++++++++---------
 camldebug.el  |  8 ++++----
 inf-caml.el   | 20 ++++++++++----------
 8 files changed, 62 insertions(+), 62 deletions(-)

diff --git a/Makefile b/Makefile
index 77aa0c6..6475be9 100644
--- a/Makefile
+++ b/Makefile
@@ -41,6 +41,7 @@ COMPILECMD=(progn \
 
 install:
        @if test "$(EMACSDIR)" = ""; then \
+         $(EMACS) --batch --eval 't; see PR#5403'; \
          set xxx `($(EMACS) --batch --eval "(mapcar 'print load-path)") \
                                2>/dev/null | \
                   sed -n -e 's/^"\(.*\/site-lisp\).*/\1/gp' | \
diff --git a/README b/README
index ea82a9f..9c30c88 100644
--- a/README
+++ b/README
@@ -123,7 +123,7 @@ Version 1.07:
 
 Version 1.06:
 ------------
-* new keywords in O'Caml 1.06
+* new keywords in Objective Caml 1.06
 
 * compatibility with GNU Emacs 20
 
@@ -153,7 +153,7 @@ Version 1.03b:
     (setq caml-quote-char "`")
     (setq inferior-caml-program "camllight")
   Literals will be correctly understood and highlighted. However,
-  indentation rules are still Objective Caml's: this just happens to
+  indentation rules are still OCaml's: this just happens to
   work well in most cases, but is only intended for occasional use.
 
 * as many people asked for it, application is now indented. This seems
@@ -167,10 +167,10 @@ Version 1.03b:
 
 Version 1.03:
 ------------
-* support of Objective Caml and Objective Label.
+* support of OCaml and Objective Label.
 
 * an indentation very close to mine, which happens to be the same as
-  Xavier's, since the sources of the Objective Caml compiler do not
+  Xavier's, since the sources of the OCaml compiler do not
   change if you indent them in this mode.
 
 * highlighting.
@@ -178,7 +178,7 @@ Version 1.03:
 Some remarks about the style supported:
 --------------------------------------
 
-Since Objective Caml's syntax is very liberal (more than 100
+Since OCaml's syntax is very liberal (more than 100
 shift-reduce conflicts with yacc), automatic indentation is far from
 easy. Moreover, you expect the indentation to be not purely syntactic,
 but also semantic: reflecting the meaning of your program.
diff --git a/README.itz b/README.itz
index 8e1366f..7bcc7aa 100644
--- a/README.itz
+++ b/README.itz
@@ -1,7 +1,7 @@
 DESCRIPTION:
 
-This directory contains files to help editing Caml code, running a
-Caml toplevel, and running the Caml debugger under the Gnu Emacs editor.
+This directory contains files to help editing OCaml code, running a
+OCaml toplevel, and running the OCaml debugger under the Gnu Emacs editor.
 
 AUTHORS:
 
@@ -13,10 +13,10 @@ camldebug.el is derived from FSF code.
 
 CONTENTS:
 
-    caml.el         A major mode for editing Caml code in Gnu Emacs
-    inf-caml.el     To run a Caml toplevel under Emacs, with input and
+    caml.el         A major mode for editing OCaml code in Gnu Emacs
+    inf-caml.el     To run a OCaml toplevel under Emacs, with input and
                     output in an Emacs buffer.
-    camldebug.el    To run the Caml debugger under Emacs.
+    camldebug.el    To run the OCaml debugger under Emacs.
 
 
 NOTE FOR EMACS 18 USERS:
@@ -29,13 +29,13 @@ USAGE:
 Add the following lines to your .emacs file:
 
 (setq auto-mode-alist (cons '("\\.ml[iylp]?" . caml-mode) auto-mode-alist))
-(autoload 'caml-mode "caml" "Major mode for editing Caml code." t)
-(autoload 'run-caml "inf-caml" "Run an inferior Caml process." t)
-(autoload 'camldebug "camldebug" "Run the Caml debugger." t)
+(autoload 'caml-mode "caml" "Major mode for editing OCaml code." t)
+(autoload 'run-caml "inf-caml" "Run an inferior OCaml process." t)
+(autoload 'camldebug "camldebug" "Run the OCaml debugger." t)
 
 The Caml major mode is triggered by visiting a file with extension .ml,
 .mli, .mly. .mll or .mlp, or manually by M-x caml-mode. It gives you the
-correct syntax table for the Caml language. For a brief description of
+correct syntax table for the OCaml language. For a brief description of
 the indentation capabilities, see below under NEWS.
 
 The Caml mode also allows you to run batch Caml compilations from
@@ -44,16 +44,16 @@ sets the point at the beginning of the erroneous program 
fragment, and
 the mark at the end. Under Emacs 19, the program fragment is
 temporarily highlighted.
 
-M-x run-caml starts a Caml toplevel with input and output in an Emacs
+M-x run-caml starts an OCaml toplevel with input and output in an Emacs
 buffer named *inferior-caml*. This gives you the full power of Emacs
-to edit the input to the Caml toplevel. This mode is based on comint
+to edit the input to the OCaml toplevel. This mode is based on comint
 so you get all the usual comint features, including command history.
 
 After M-x run-caml, typing C-c C-e or M-C-x in a buffer in Caml mode
-sends the current phrase (containing the point) to the Caml toplevel,
+sends the current phrase (containing the point) to the OCaml toplevel,
 and evaluates it.
 
-M-x camldebug FILE starts the Caml debugger camldebug on the executable
+M-x camldebug FILE starts the OCaml debugger camldebug on the executable
 FILE, with input and output in an Emacs buffer named *camldebug-FILE*.
 For a brief description of the commands available in this buffer, see
 NEWS below.
diff --git a/caml-hilit.el b/caml-hilit.el
index 0d437c5..25376eb 100644
--- a/caml-hilit.el
+++ b/caml-hilit.el
@@ -53,7 +53,7 @@
           "\\|\|\\|->\\|&\\|#")
          nil 'keyword)
    '(";" nil struct))
-  "Hilit19 patterns used for Caml mode")
+  "Hilit19 patterns used for OCaml mode")
 
 (hilit-set-mode-patterns 'caml-mode caml-mode-patterns)
 (hilit-set-mode-patterns
diff --git a/caml-types.el b/caml-types.el
index 70d38bc..ac3fb1b 100644
--- a/caml-types.el
+++ b/caml-types.el
@@ -38,7 +38,7 @@ Their format is:
   <SP> is a space character (ASCII 0x20)
   <LF> is a line-feed character (ASCII 0x0A)
   num is a sequence of decimal digits
-  filename is a string with the lexical conventions of O'Caml
+  filename is a string with the lexical conventions of OCaml
   open-paren is an open parenthesis (ASCII 0x28)
   close-paren is a closed parenthesis (ASCII 0x29)
   data is any sequence of characters where <LF> is always followed by
@@ -411,8 +411,7 @@ See `caml-types-location-re' for annotation file format.
         (unless (caml-types-not-in-file l-file r-file target-file)
           (setq annotation ())
           (while (next-annotation)
-            (cond ((looking-at
-                    "^\\([a-z]+\\)(\n  \\(\\([^\n)]\\|.)\\|\n[^)]\\)*\\)\n)")
+            (cond ((looking-at "^\\([a-z]+\\)(\n  \\(\\(.*\n  \\)*.*\\)\n)")
                    (let ((kind (caml-types-hcons (match-string 1) table))
                          (info (caml-types-hcons (match-string 2) table)))
                      (setq annotation (cons (cons kind info) annotation))))))
@@ -595,7 +594,7 @@ The function uses two overlays.
  . One overlay delimits the largest region whose all subnodes
    are well-typed.
  . Another overlay delimits the current node under the mouse (whose type
-   annotation is beeing displayed).
+   annotation is being displayed).
 "
   (interactive "e")
   (set-buffer (window-buffer (caml-event-window event)))
@@ -687,30 +686,30 @@ The function uses two overlays.
                            target-pos
                            (vector target-file target-line target-bol cnum))
                      (save-excursion
-                       (setq node (caml-types-find-location "type"
-                                   target-pos () target-tree))
+                       (setq node (caml-types-find-location target-pos "type" 
()
+                                                            target-tree))
                        (set-buffer caml-types-buffer)
                        (erase-buffer)
                        (cond
-                        (node
-                         (setq Left
-                               (caml-types-get-pos target-buf (elt node 0))
-                               Right
-                               (caml-types-get-pos target-buf (elt node 1)))
-                         (move-overlay
-                          caml-types-expr-ovl Left Right target-buf)
-                         (setq limits
-                               (caml-types-find-interval target-buf
-                                                         target-pos node)
-                               type (elt node 2))
-                         )
-                        (t
+                        ((null node)
                          (delete-overlay caml-types-expr-ovl)
                          (setq type "*no type information*")
                          (setq limits
                                (caml-types-find-interval
-                                target-buf target-pos target-tree))
+                                target-buf target-pos target-tree)))
+                        (t
+                         (let ((left
+                                (caml-types-get-pos target-buf (elt node 0)))
+                               (right
+                                (caml-types-get-pos target-buf (elt node 1))))
+                         (move-overlay
+                          caml-types-expr-ovl left right target-buf)
+                         (setq limits
+                               (caml-types-find-interval target-buf
+                                                         target-pos node)
+                               type (cdr (assoc "type" (elt node 2))))
                          ))
+                        )
                        (setq mes (format "type: %s" type))
                        (insert type)
                        ))
diff --git a/camldebug.el b/camldebug.el
index 199a6cc..790eb6e 100644
--- a/camldebug.el
+++ b/camldebug.el
@@ -89,7 +89,7 @@
 
 (define-derived-mode camldebug-mode comint-mode "Inferior CDB"
 
-  "Major mode for interacting with an inferior Camldebug process.
+  "Major mode for interacting with an inferior ocamldebug process.
 
 The following commands are available:
 
@@ -575,7 +575,7 @@ the camldebug commands `cd DIR' and `directory'."
         (let ((process-window))
           ;; it does not seem necessary to save excursion here,
           ;; since set-buffer as a temporary effect.
-          ;; comint-output-filter explicitly avoids it. 
+          ;; comint-output-filter explicitly avoids it.
           ;; in version 23, it prevents the marker to stay at end of buffer
           ;; (save-excursion
             (set-buffer (process-buffer proc))
@@ -595,8 +595,8 @@ the camldebug commands `cd DIR' and `directory'."
                                       (get-buffer-window (current-buffer))))
             ;; Insert the text, moving the process-marker.
             (comint-output-filter proc output)
-          ;; ) 
-          ;; this was the end of save-excursion. 
+          ;; )
+          ;; this was the end of save-excursion.
           ;; if save-excursion is used (comint-next-prompt 1) would be needed
           ;; to move the mark past then next prompt, but this is not as good
           ;; as solution.
diff --git a/caml.el b/caml.el
index 342305d..d1127f7 100644
--- a/caml.el
+++ b/caml.el
@@ -12,7 +12,7 @@
 
 ;(* $Id$ *)
 
 ;;; caml.el --- O'Caml code editing commands for Emacs
 
 ;; Xavier Leroy, july 1993.
 
@@ -484,7 +484,7 @@ have caml-electric-indent on, which see.")
   "Hook for caml-mode")
 
 (defun caml-mode ()
-  "Major mode for editing Caml code.
+  "Major mode for editing OCaml code.
 
 \\{caml-mode-map}"
 
@@ -588,7 +588,7 @@ have caml-electric-indent on, which see.")
 ;;; subshell support
 
 (defun caml-eval-region (start end)
-  "Send the current region to the inferior Caml process."
+  "Send the current region to the inferior OCaml process."
   (interactive"r")
   (require 'inf-caml)
   (inferior-caml-eval-region start end))
@@ -596,7 +596,7 @@ have caml-electric-indent on, which see.")
 ;; old version ---to be deleted later
 ;
 ; (defun caml-eval-phrase ()
 ;   "Send the current Caml phrase to the inferior Caml process."
 ;   (interactive)
 ;   (save-excursion
 ;     (let ((bounds (caml-mark-phrase)))
@@ -825,7 +825,7 @@ from an error message produced by camlc.")
 ;that way we get our effect even when we do \C-x` in compilation buffer
 
 (defadvice next-error (after caml-next-error activate)
- "Reads the extra positional information provided by the Caml compiler.
+ "Reads the extra positional information provided by the OCaml compiler.
 
 Puts the point and the mark exactly around the erroneous program
 fragment. The erroneous fragment is also temporarily highlighted if
@@ -903,7 +903,7 @@ whole string."
 ;; itz Thu Sep 24 19:02:42 PDT 1998 this is to have some level of
 ;; comfort when sending phrases to the toplevel and getting errors.
 (defun caml-goto-phrase-error ()
-  "Find the error location in current Caml phrase."
+  "Find the error location in current OCaml phrase."
   (interactive)
   (require 'inf-caml)
   (let ((bounds (save-excursion (caml-mark-phrase))))
@@ -984,7 +984,7 @@ to the end.
     beg))
 
 (defun caml-mark-phrase (&optional min-pos max-pos)
-  "Put mark at end of this Caml phrase, point at beginning.
+  "Put mark at end of this OCaml phrase, point at beginning.
 "
   (interactive)
   (let* ((beg (caml-find-phrase min-pos max-pos)) (end (point)))
@@ -1756,7 +1756,7 @@ by |, insert one."
       (goto-char (match-end 0))))
 
 ;; to mark phrases, so that repeated calls will take several of them
-;; knows little about Ocaml appart literals and comments, so it should work
+;; knows little about OCaml except literals and comments, so it should work
 ;; with other dialects as long as ;; marks the end of phrase.
 
 (defun caml-indent-phrase (arg)
@@ -1912,7 +1912,7 @@ with prefix arg, indent that many phrases starting with 
the current phrase."
     (beginning-of-line 1)
     (backward-char 4)))
 
-(autoload 'run-caml "inf-caml" "Run an inferior Caml process." t)
+(autoload 'run-caml "inf-caml" "Run an inferior OCaml process." t)
 
 (autoload 'caml-types-show-type "caml-types"
   "Show the type of expression or pattern at point." t)
@@ -12,7 +12,7 @@
 ;(* $Id$ *)
 
-;;; caml.el --- O'Caml code editing commands for Emacs
+;;; caml.el --- OCaml code editing commands for Emacs
 
 ;; Xavier Leroy, july 1993.
@@ -596,7 +596,7 @@ have caml-electric-indent on, which see.")
 ;
 ; (defun caml-eval-phrase ()
-;   "Send the current Caml phrase to the inferior Caml process."
+;   "Send the current OCaml phrase to the inferior Caml process."
 ;   (interactive)
 ;   (save-excursion
diff --git a/inf-caml.el b/inf-caml.el
index 4b9cd6b..5b864ef 100644
--- a/inf-caml.el
+++ b/inf-caml.el
@@ -12,7 +12,7 @@
 
 ;(* $Id$ *)
 
 ;;; inf-caml.el --- run the Caml toplevel in an Emacs buffer
 
 ;; Xavier Leroy, july 1993.
 
@@ -37,14 +37,14 @@
   (setq inferior-caml-mode-map
         (copy-keymap comint-mode-map)))
 
 ;; Augment Caml mode, so you can process Caml code in the source files.
 
 (defvar inferior-caml-program "ocaml"
-  "*Program name for invoking an inferior Caml from Emacs.")
+  "*Program name for invoking an inferior OCaml from Emacs.")
 
 (defun inferior-caml-mode ()
-  "Major mode for interacting with an inferior Caml process.
-Runs a Caml toplevel as a subprocess of Emacs, with I/O through an
+  "Major mode for interacting with an inferior OCaml process.
+Runs an OCaml toplevel as a subprocess of Emacs, with I/O through an
 Emacs buffer. A history of input phrases is maintained. Phrases can
 be sent from another buffer in Caml mode.
 
@@ -95,7 +95,7 @@ be sent from another buffer in Caml mode.
 
 (defun inferior-caml-mode-output-hook ()
   (set-variable 'comint-output-filter-functions
-        (list (function inferior-caml-signal-output)) 
+        (list (function inferior-caml-signal-output))
         t))
 (add-hook 'inferior-caml-mode-hooks 'inferior-caml-mode-output-hook)
 
@@ -106,7 +106,7 @@ be sent from another buffer in Caml mode.
     (if (not cmd)
         (if (comint-check-proc inferior-caml-buffer-name)
             (setq cmd inferior-caml-program)
-          (setq cmd (read-from-minibuffer "Caml toplevel to run: "
+          (setq cmd (read-from-minibuffer "OCaml toplevel to run: "
                                           inferior-caml-program))))
     (setq inferior-caml-program cmd)
     (let ((cmdlist (inferior-caml-args-to-list cmd))
@@ -124,11 +124,11 @@ be sent from another buffer in Caml mode.
 ;;  caml-run-process-when-needed
 
 (defun run-caml (&optional cmd)
-  "Run an inferior Caml process.
+  "Run an inferior OCaml process.
 Input and output via buffer `*inferior-caml*'."
   (interactive
    (list (if (not (comint-check-proc inferior-caml-buffer-name))
-             (read-from-minibuffer "Caml toplevel to run: "
+             (read-from-minibuffer "OCaml toplevel to run: "
                                    inferior-caml-program))))
   (caml-run-process-if-needed cmd)
   (switch-to-buffer-other-window inferior-caml-buffer-name))
@@ -174,7 +174,7 @@ Input and output via buffer `*inferior-caml*'."
 ;; patched by Didier to move cursor after evaluation
 
 (defun inferior-caml-eval-region (start end)
-  "Send the current region to the inferior Caml process."
+  "Send the current region to the inferior OCaml process."
   (interactive "r")
   (save-excursion (caml-run-process-if-needed))
   (save-excursion
@@ -12,7 +12,7 @@
 ;(* $Id$ *)
 
-;;; inf-caml.el --- run the Caml toplevel in an Emacs buffer
+;;; inf-caml.el --- run the OCaml toplevel in an Emacs buffer
 
 ;; Xavier Leroy, july 1993.
@@ -37,14 +37,14 @@
         (copy-keymap comint-mode-map)))
 
-;; Augment Caml mode, so you can process Caml code in the source files.
+;; Augment Caml mode, so you can process OCaml code in the source files.
 
 (defvar inferior-caml-program "ocaml"



reply via email to

[Prev in Thread] Current Thread [Next in Thread]